{ lib, pkgs, config, modulesPath, inputs, ... }:

with lib;
let
  defaultUser = "michael";
in
{
  imports = [
    "${modulesPath}/profiles/minimal.nix"

    inputs.nixos-wsl.nixosModules.wsl
  ];

  wsl = {
    enable = true;
    automountPath = "/mnt";
    defaultUser = defaultUser;
    startMenuLaunchers = true;

    # Enable integration with Docker Desktop (needs to be installed)
    # docker.enable = true;
  };

  time.timeZone = "America/New_York";

  programs.adb.enable = true;

  # Required because for some reason WSL kernel doesn't play well with nftables
  networking.firewall.package = pkgs.iptables-legacy;

  environment.systemPackages = with pkgs; [
  	wget
  ];

  # Proxychains
  programs.proxychains = {
  	enable = true;
  	proxies.main = {
  		enable = true;
  		type = "http";
  		host = "172.21.32.1";
  		port = 1080;
  	};
  };

  users.users.${defaultUser} = {
  	uid = pkgs.lib.mkForce 1001;
    extraGroups = [ "wheel" "docker" "podman" ];
    shell = pkgs.zsh;
  };
}
